#include <stdlib.h>
#include <iostream>

#include <QtCore/QList>
#include <QtCore/QTime>
#include <QtCore/QDebug>

#include "skypoint.h"
#include "ksnumbers.h"

#define NPOINTS 36000

int main( int argc, char *argv[] )
{
  QList<SkyPoint> sp1;
  QList<SkyPoint*> sp2;

  KSNumbers num( J2000 ); //USe J2000 for a date
  dms LST( 180.0 ); //Set LST to 12h
  dms lat( 32.221 ); //Tucson, AZ latitude
  QTime t;

  std::cout << "Populating list 1" << std::endl;
  t.start();
  for ( int i=0; i < NPOINTS; ++i ) {
    sp1.append( SkyPoint( 0.01*float(i)/15.0, 0.0 ) );
  }
  qDebug( "elapsed time: %d ms", t.elapsed() );

  std::cout << "Populating list 2" << std::endl;
  t.start();
  for ( int i=0; i < NPOINTS; ++i ) {
    sp2.append( new SkyPoint( 0.01*float(i)/15.0, 0.0 ) );
  }
  qDebug( "elapsed time: %d ms", t.elapsed() );

  std::cout << "Converting coordinates in list 1" << std::endl;
  t.start();
  for ( int i=0; i < sp1.size(); ++i ) {
    sp1[i].EquatorialToHorizontal( &LST, &lat );
  }
  qDebug( "elapsed time: %d ms", t.elapsed() );

  std::cout << "Converting coordinates in list 2" << std::endl;
  t.start();
  for ( int i=0; i < sp2.size(); ++i ) {
    sp2[i]->EquatorialToHorizontal( &LST, &lat );
  }
  qDebug( "elapsed time: %d ms", t.elapsed() );
}

